///////////////////////////////////////////////////////////////////////////////
/// \file transform.hpp
/// Includes all the transforms in the transform/ sub-directory.
//
//  Copyright 2008 Eric Niebler. Distributed under the Boost
//  Software License, Version 1.0. (See accompanying file
//  LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)

#ifndef BOOST_PROTO_TRANSFORM_HPP_EAN_06_23_2007
#define BOOST_PROTO_TRANSFORM_HPP_EAN_06_23_2007

#include <boost/xpressive/proto/detail/prefix.hpp> // must be first include
#include <boost/xpressive/proto/transform/arg.hpp>
#include <boost/xpressive/proto/transform/bind.hpp>
#include <boost/xpressive/proto/transform/call.hpp>
#include <boost/xpressive/proto/transform/fold.hpp>
#include <boost/xpressive/proto/transform/fold_tree.hpp>
#include <boost/xpressive/proto/transform/make.hpp>
#include <boost/xpressive/proto/transform/pass_through.hpp>
#include <boost/xpressive/proto/transform/when.hpp>
#include <boost/xpressive/proto/detail/suffix.hpp> // must be last include

#endif
